@@ -297,10 +297,12 @@ void MainWindow::showAbout()
 {
     qDebug("MainWindow::showAbout");
 
-    QString title = tr("About Pomodoro ") + POMODORO_VERSION;
+    QString title = tr("About");
     QString text =
-            tr("Copyright (C) 2010, Sakari Hyoty\n\n"
-               "See detailed licensing information from ") + POMODORO_README_FILE + " .";
+            tr("Pomodoro  Copyright (C) 2010 Sakari Hyoty\n\n"
+               "This program comes with ABSOLUTELY NO WARRANTY. This is free software, "
+               "and you are welcome to redistribute it under certain conditions; see `%1' "
+               "for details.").arg(POMODORO_README_FILE);
 
     QMessageBox::about(this, title, text);
 }
